==> ads-lib-1.31.0-sources.jar: com/google/api/ads/common/lib/conf/ProductConfiguration.java <==
// Copyright 2012 Google Inc. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.google.api.ads.common.lib.conf;

import com.google.inject.Inject;
import com.google.inject.name.Named;

import org.apache.commons.configuration.Configuration;

/**
 * Configuration of product/framework properties.
 *
 * @author Adam Rogal
 */
public class ProductConfiguration extends BaseConfiguration {

  /**
   * Configuration keys.
   */
  public static final String PRODUCT_NAME_PREFIX_KEY = "product.name.prefix";
  public static final String PRODUCT_NAME_POSTFIX_KEY = "product.name.postfix";

  /**
   * Constructor.
   *
   * @param configuration the product configuration
   */
  @Inject
  public ProductConfiguration(@Named("product") Configuration configuration) {
    super(configuration);
  }

  /**
   * Gets the product name prefix.
   */
  public String getProductNamePrefix() {
    return getString(PRODUCT_NAME_PREFIX_KEY);
  }

  /**
   * Gets the product name postfix.
   */
  public String getProductNamePostfix() {
    return getString(PRODUCT_NAME_POSTFIX_KEY);
  }
}

==> ads-lib-2.21.0-sources.jar: com/google/api/ads/common/lib/conf/ProductConfiguration.java <==
// Copyright 2012 Google Inc. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.google.api.ads.common.lib.conf;

import com.google.inject.name.Named;

import org.apache.commons.configuration.Configuration;

import javax.inject.Inject;

/**
 * Configuration of product/framework properties.
 */
public class ProductConfiguration extends BaseConfiguration {

  /**
   * Configuration keys.
   */
  public static final String PRODUCT_NAME_PREFIX_KEY = "product.name.prefix";
  public static final String PRODUCT_NAME_POSTFIX_KEY = "product.name.postfix";

  /**
   * Constructor.
   *
   * @param configuration the product configuration
   */
  @Inject
  public ProductConfiguration(@Named("product") Configuration configuration) {
    super(configuration);
  }

  /**
   * Gets the product name prefix.
   */
  public String getProductNamePrefix() {
    return getString(PRODUCT_NAME_PREFIX_KEY);
  }

  /**
   * Gets the product name postfix.
   */
  public String getProductNamePostfix() {
    return getString(PRODUCT_NAME_POSTFIX_KEY);
  }
}
